Documentation
¶
Index ¶
- type AdditionalPropEscape
- type AdditionalPropEscapeRaw
- type AdditionalPropEscapeU003chmu003eObject
- type AdditionalPropEscapeU003chmu003eObjectRaw
- type AdditionalPropEscapeU2728Object
- type AdditionalPropEscapeU2728ObjectRaw
- type All
- type AllDateDate
- type AllDateNanoDate
- type AllNestedNameObject
- type AllNestedNameObjectRaw
- type AllNestedObject
- type AllNestedObjectRaw
- type AllObjectNameObject
- type AllObjectNameObjectRaw
- type AllObjectObject
- type AllObjectObjectRaw
- type AllOptional
- type AllOptionalDateDate
- type AllOptionalDateNanoDate
- type AllOptionalNestedNameObject
- type AllOptionalNestedNameObjectRaw
- type AllOptionalNestedObject
- type AllOptionalNestedObjectRaw
- type AllOptionalObjectNameObject
- type AllOptionalObjectNameObjectRaw
- type AllOptionalObjectObject
- type AllOptionalObjectObjectRaw
- type AllOptionalRaw
- type AllRaw
- type Conversion
- type ConversionMultipleOptionalNameObject
- type ConversionMultipleOptionalNameObjectRaw
- type ConversionMultipleOptionalNested
- type ConversionMultipleOptionalNestedRaw
- type ConversionMultipleRequiredNameObject
- type ConversionMultipleRequiredNameObjectRaw
- type ConversionMultipleRequiredNested
- type ConversionMultipleRequiredNestedRaw
- type ConversionRaw
- type ConversionSingleOptionalNameObject
- type ConversionSingleOptionalNameObjectRaw
- type ConversionSingleOptionalObject
- type ConversionSingleOptionalObjectRaw
- type ConversionSingleRequiredNameObject
- type ConversionSingleRequiredNameObjectRaw
- type ConversionSingleRequiredObject
- type ConversionSingleRequiredObjectRaw
- type Dynamic
- type DynamicNestedInheritNameObject
- type DynamicNestedInheritNameObjectRaw
- type DynamicNestedInheritNested
- type DynamicNestedInheritNestedRaw
- type DynamicNestedRuntimeNameObject
- type DynamicNestedRuntimeNameObjectRaw
- type DynamicNestedRuntimeNested
- type DynamicNestedRuntimeNestedRaw
- type DynamicNestedStrictNameObject
- type DynamicNestedStrictNameObjectRaw
- type DynamicNestedStrictNested
- type DynamicNestedStrictNestedRaw
- type DynamicObjectFalseNameObject
- type DynamicObjectFalseNameObjectRaw
- type DynamicObjectFalseObject
- type DynamicObjectFalseObjectRaw
- type DynamicRaw
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AdditionalPropEscape ¶
type AdditionalPropEscape struct {
U003chmu003e AdditionalPropEscapeU003chmu003eObject `json:"<hm>"`
U2728 AdditionalPropEscapeU2728Object `json:"✨"`
AdditionalProperties_ map[string]any
}
func (AdditionalPropEscape) MarshalJSON ¶
func (d AdditionalPropEscape) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (AdditionalPropEscape) ToRaw ¶
func (d AdditionalPropEscape) ToRaw() AdditionalPropEscapeRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*AdditionalPropEscape) UnmarshalJSON ¶
func (d *AdditionalPropEscape) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type AdditionalPropEscapeRaw ¶
type AdditionalPropEscapeRaw struct {
U003chmu003e elastic.Elastic[AdditionalPropEscapeU003chmu003eObjectRaw] `json:"<hm>,omitempty"`
U2728 elastic.Elastic[AdditionalPropEscapeU2728ObjectRaw] `json:"✨,omitempty"`
AdditionalProperties_ map[string]any
}
func (AdditionalPropEscapeRaw) MarshalJSON ¶
func (d AdditionalPropEscapeRaw) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (AdditionalPropEscapeRaw) ToPlain ¶
func (d AdditionalPropEscapeRaw) ToPlain() AdditionalPropEscape
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*AdditionalPropEscapeRaw) UnmarshalJSON ¶
func (d *AdditionalPropEscapeRaw) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type AdditionalPropEscapeU003chmu003eObject ¶
type AdditionalPropEscapeU003chmu003eObject struct {
U0026mahu0026 string `json:"&mah&"`
FooBar__ *struct{} `json:"__foo_bar,omitempty"`
AdditionalProperties_ map[string]any
}
func (AdditionalPropEscapeU003chmu003eObject) MarshalJSON ¶
func (d AdditionalPropEscapeU003chmu003eObject) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (AdditionalPropEscapeU003chmu003eObject) ToRaw ¶
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*AdditionalPropEscapeU003chmu003eObject) UnmarshalJSON ¶
func (d *AdditionalPropEscapeU003chmu003eObject) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type AdditionalPropEscapeU003chmu003eObjectRaw ¶
type AdditionalPropEscapeU003chmu003eObjectRaw struct {
U0026mahu0026 elastic.Elastic[string] `json:"&mah&,omitempty"`
FooBar__ elastic.Elastic[*struct{}] `json:"__foo_bar,omitempty"`
AdditionalProperties_ map[string]any
}
func (AdditionalPropEscapeU003chmu003eObjectRaw) MarshalJSON ¶
func (d AdditionalPropEscapeU003chmu003eObjectRaw) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (AdditionalPropEscapeU003chmu003eObjectRaw) ToPlain ¶
func (d AdditionalPropEscapeU003chmu003eObjectRaw) ToPlain() AdditionalPropEscapeU003chmu003eObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*AdditionalPropEscapeU003chmu003eObjectRaw) UnmarshalJSON ¶
func (d *AdditionalPropEscapeU003chmu003eObjectRaw) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type AdditionalPropEscapeU2728Object ¶
type AdditionalPropEscapeU2728Object struct {
Yay string `json:"yay"`
AdditionalProperties_ map[string]any
}
func (AdditionalPropEscapeU2728Object) MarshalJSON ¶
func (d AdditionalPropEscapeU2728Object) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (AdditionalPropEscapeU2728Object) ToRaw ¶
func (d AdditionalPropEscapeU2728Object) ToRaw() AdditionalPropEscapeU2728ObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*AdditionalPropEscapeU2728Object) UnmarshalJSON ¶
func (d *AdditionalPropEscapeU2728Object) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type AdditionalPropEscapeU2728ObjectRaw ¶
type AdditionalPropEscapeU2728ObjectRaw struct {
Yay elastic.Elastic[string] `json:"yay,omitempty"`
AdditionalProperties_ map[string]any
}
func (AdditionalPropEscapeU2728ObjectRaw) MarshalJSON ¶
func (d AdditionalPropEscapeU2728ObjectRaw) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (AdditionalPropEscapeU2728ObjectRaw) ToPlain ¶
func (d AdditionalPropEscapeU2728ObjectRaw) ToPlain() AdditionalPropEscapeU2728Object
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*AdditionalPropEscapeU2728ObjectRaw) UnmarshalJSON ¶
func (d *AdditionalPropEscapeU2728ObjectRaw) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type All ¶
type All struct {
Agg fielddatatype.AggregateMetricDouble `json:"agg"`
Alias *struct{} `json:"alias,omitempty"`
Blob []byte `json:"blob"`
Bool fielddatatype.Boolean `json:"bool"`
Byte int8 `json:"byte"`
Comp string `json:"comp"`
ConstantKwd string `json:"constant_kwd"`
Date AllDateDate `json:"date"`
DateNano AllDateNanoDate `json:"dateNano"`
DateRange fielddatatype.Range[builtin.Default] `json:"date_range"`
DenseVector [3]float64 `json:"dense_vector"`
Double float64 `json:"double"`
DoubleRange fielddatatype.Range[float64] `json:"double_range"`
Flattened map[string]any `json:"flattened"`
Float float32 `json:"float"`
FloatRange fielddatatype.Range[float32] `json:"float_range"`
Geopoint fielddatatype.GeoPoint `json:"geopoint"`
Geoshape fielddatatype.GeoShape `json:"geoshape"`
HalfFloat float32 `json:"half_float"`
Histogram fielddatatype.Histogram `json:"histogram"`
Integer int32 `json:"integer"`
IntegerRange fielddatatype.Range[int32] `json:"integer_range"`
IpAddr netip.Addr `json:"ip_addr"`
IpRange fielddatatype.Range[netip.Addr] `json:"ip_range"`
Join map[string]any `json:"join"`
Kwd string `json:"kwd"`
Long int64 `json:"long"`
LongRange fielddatatype.Range[int64] `json:"long_range"`
Nested AllNestedObject `json:"nested"`
Object AllObjectObject `json:"object"`
Point map[string]any `json:"point"`
Query map[string]any `json:"query"`
RankFeature float64 `json:"rank_feature"`
RankFeatures map[string]float64 `json:"rank_features"`
ScaledFloat float64 `json:"scaled_float"`
SearchAsYouType string `json:"search_as_you_type"`
Shape fielddatatype.GeoShape `json:"shape"`
Short int16 `json:"short"`
Text string `json:"text"`
TextWTokenCount string `json:"text_w_token_count"`
UnsignedLong uint64 `json:"unsigned_long"`
Version string `json:"version"`
Wildcard string `json:"wildcard"`
}
type AllDateDate ¶
AllDateDate represents the date or the date_nanos mapping field type. It implements json.Unmarshaler so that it can be directly unmarshaled from all possible formats specified in corresponding `format` field.
Allowed formats are:
- 2006-01-02 15:04:05
- 2006-01-02
- int as epoch_millis
It also implements json.Marshaler. It will be marshaled into string formatted in 2006-01-02 15:04:05 layout.
func (AllDateDate) MarshalJSON ¶
func (t AllDateDate) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (*AllDateDate) UnmarshalJSON ¶
func (t *AllDateDate) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler
type AllDateNanoDate ¶
AllDateNanoDate represents the date or the date_nanos mapping field type. It implements json.Unmarshaler so that it can be directly unmarshaled from all possible formats specified in corresponding `format` field.
Allowed formats are:
- 2006-01-02T15:04:05.000000000Z0700
- 2006-01-02
- int as epoch_second
It also implements json.Marshaler. It will be marshaled into string formatted in 2006-01-02T15:04:05.000000000Z0700 layout.
func (AllDateNanoDate) MarshalJSON ¶
func (t AllDateNanoDate) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (AllDateNanoDate) String ¶
func (t AllDateNanoDate) String() string
String implements fmt.Stringer
func (*AllDateNanoDate) UnmarshalJSON ¶
func (t *AllDateNanoDate) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler
type AllNestedNameObject ¶
func (AllNestedNameObject) ToRaw ¶
func (d AllNestedNameObject) ToRaw() AllNestedNameObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllNestedNameObjectRaw ¶
type AllNestedNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
}
func (AllNestedNameObjectRaw) ToPlain ¶
func (d AllNestedNameObjectRaw) ToPlain() AllNestedNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllNestedObject ¶
type AllNestedObject struct {
Age int32 `json:"age"`
Name AllNestedNameObject `json:"name"`
}
func (AllNestedObject) ToRaw ¶
func (d AllNestedObject) ToRaw() AllNestedObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllNestedObjectRaw ¶
type AllNestedObjectRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[AllNestedNameObjectRaw] `json:"name,omitempty"`
}
func (AllNestedObjectRaw) ToPlain ¶
func (d AllNestedObjectRaw) ToPlain() AllNestedObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllObjectNameObject ¶
func (AllObjectNameObject) ToRaw ¶
func (d AllObjectNameObject) ToRaw() AllObjectNameObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllObjectNameObjectRaw ¶
type AllObjectNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
}
func (AllObjectNameObjectRaw) ToPlain ¶
func (d AllObjectNameObjectRaw) ToPlain() AllObjectNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllObjectObject ¶
type AllObjectObject struct {
Age int32 `json:"age"`
Name AllObjectNameObject `json:"name"`
}
func (AllObjectObject) ToRaw ¶
func (d AllObjectObject) ToRaw() AllObjectObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllObjectObjectRaw ¶
type AllObjectObjectRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[AllObjectNameObjectRaw] `json:"name,omitempty"`
}
func (AllObjectObjectRaw) ToPlain ¶
func (d AllObjectObjectRaw) ToPlain() AllObjectObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllOptional ¶
type AllOptional struct {
Agg *fielddatatype.AggregateMetricDouble `json:"agg"`
Alias *struct{} `json:"alias,omitempty"`
Blob *[][]byte `json:"blob"`
Bool *[]fielddatatype.Boolean `json:"bool"`
Byte *[]int8 `json:"byte"`
Comp *[]string `json:"comp,omitempty"`
ConstantKwd *[]string `json:"constant_kwd,omitempty"`
Date *[]AllOptionalDateDate `json:"date"`
DateNano *[]AllOptionalDateNanoDate `json:"dateNano"`
DateRange *[]fielddatatype.Range[builtin.Default] `json:"date_range"`
DenseVector *[3]float64 `json:"dense_vector,omitempty"`
Double *[]float64 `json:"double"`
DoubleRange *[]fielddatatype.Range[float64] `json:"double_range"`
Flattened *[]map[string]any `json:"flattened"`
Float *[]float32 `json:"float"`
FloatRange *[]fielddatatype.Range[float32] `json:"float_range"`
Geopoint *[]fielddatatype.GeoPoint `json:"geopoint"`
Geoshape *[]fielddatatype.GeoShape `json:"geoshape"`
HalfFloat *[]float32 `json:"half_float"`
Histogram *fielddatatype.Histogram `json:"histogram"`
Integer *[]int32 `json:"integer"`
IntegerRange *[]fielddatatype.Range[int32] `json:"integer_range"`
IpAddr *[]netip.Addr `json:"ip_addr"`
IpRange *[]fielddatatype.Range[netip.Addr] `json:"ip_range"`
Join *map[string]any `json:"join,omitempty"`
Kwd *[]string `json:"kwd"`
Long *[]int64 `json:"long"`
LongRange *[]fielddatatype.Range[int64] `json:"long_range"`
Nested *[]AllOptionalNestedObject `json:"nested"`
Object *[]AllOptionalObjectObject `json:"object"`
Point *[]map[string]any `json:"point"`
Query *map[string]any `json:"query,omitempty"`
RankFeature *float64 `json:"rank_feature"`
RankFeatures *[]map[string]float64 `json:"rank_features,omitempty"`
ScaledFloat *[]float64 `json:"scaled_float"`
SearchAsYouType *[]string `json:"search_as_you_type"`
Shape *[]fielddatatype.GeoShape `json:"shape"`
Short *[]int16 `json:"short"`
Text *[]string `json:"text"`
TextWTokenCount *[]string `json:"text_w_token_count"`
UnsignedLong *[]uint64 `json:"unsigned_long"`
Version *[]string `json:"version"`
Wildcard *[]string `json:"wildcard"`
}
func (AllOptional) ToRaw ¶
func (d AllOptional) ToRaw() AllOptionalRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllOptionalDateDate ¶
AllOptionalDateDate represents the date or the date_nanos mapping field type. It implements json.Unmarshaler so that it can be directly unmarshaled from all possible formats specified in corresponding `format` field.
Allowed formats are:
- 2006-01-02 15:04:05
- 2006-01-02
- int as epoch_millis
It also implements json.Marshaler. It will be marshaled into string formatted in 2006-01-02 15:04:05 layout.
func (AllOptionalDateDate) MarshalJSON ¶
func (t AllOptionalDateDate) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (AllOptionalDateDate) String ¶
func (t AllOptionalDateDate) String() string
String implements fmt.Stringer
func (*AllOptionalDateDate) UnmarshalJSON ¶
func (t *AllOptionalDateDate) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler
type AllOptionalDateNanoDate ¶
AllOptionalDateNanoDate represents the date or the date_nanos mapping field type. It implements json.Unmarshaler so that it can be directly unmarshaled from all possible formats specified in corresponding `format` field.
Allowed formats are:
- 2006-01-02T15:04:05.000000000Z0700
- 2006-01-02
- int as epoch_second
It also implements json.Marshaler. It will be marshaled into string formatted in 2006-01-02T15:04:05.000000000Z0700 layout.
func (AllOptionalDateNanoDate) MarshalJSON ¶
func (t AllOptionalDateNanoDate) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler
func (AllOptionalDateNanoDate) String ¶
func (t AllOptionalDateNanoDate) String() string
String implements fmt.Stringer
func (*AllOptionalDateNanoDate) UnmarshalJSON ¶
func (t *AllOptionalDateNanoDate) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler
type AllOptionalNestedNameObject ¶
type AllOptionalNestedNameObject struct {
First *[]string `json:"first"`
Last *[]string `json:"last"`
}
func (AllOptionalNestedNameObject) ToRaw ¶
func (d AllOptionalNestedNameObject) ToRaw() AllOptionalNestedNameObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllOptionalNestedNameObjectRaw ¶
type AllOptionalNestedNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
}
func (AllOptionalNestedNameObjectRaw) ToPlain ¶
func (d AllOptionalNestedNameObjectRaw) ToPlain() AllOptionalNestedNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllOptionalNestedObject ¶
type AllOptionalNestedObject struct {
Age *[]int32 `json:"age"`
Name *[]AllOptionalNestedNameObject `json:"name"`
}
func (AllOptionalNestedObject) ToRaw ¶
func (d AllOptionalNestedObject) ToRaw() AllOptionalNestedObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllOptionalNestedObjectRaw ¶
type AllOptionalNestedObjectRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[AllOptionalNestedNameObjectRaw] `json:"name,omitempty"`
}
func (AllOptionalNestedObjectRaw) ToPlain ¶
func (d AllOptionalNestedObjectRaw) ToPlain() AllOptionalNestedObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllOptionalObjectNameObject ¶
type AllOptionalObjectNameObject struct {
First *[]string `json:"first"`
Last *[]string `json:"last"`
}
func (AllOptionalObjectNameObject) ToRaw ¶
func (d AllOptionalObjectNameObject) ToRaw() AllOptionalObjectNameObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllOptionalObjectNameObjectRaw ¶
type AllOptionalObjectNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
}
func (AllOptionalObjectNameObjectRaw) ToPlain ¶
func (d AllOptionalObjectNameObjectRaw) ToPlain() AllOptionalObjectNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllOptionalObjectObject ¶
type AllOptionalObjectObject struct {
Age *[]int32 `json:"age"`
Name *[]AllOptionalObjectNameObject `json:"name"`
}
func (AllOptionalObjectObject) ToRaw ¶
func (d AllOptionalObjectObject) ToRaw() AllOptionalObjectObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllOptionalObjectObjectRaw ¶
type AllOptionalObjectObjectRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[AllOptionalObjectNameObjectRaw] `json:"name,omitempty"`
}
func (AllOptionalObjectObjectRaw) ToPlain ¶
func (d AllOptionalObjectObjectRaw) ToPlain() AllOptionalObjectObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllOptionalRaw ¶
type AllOptionalRaw struct {
Agg elastic.Elastic[fielddatatype.AggregateMetricDouble] `json:"agg,omitempty"`
Alias elastic.Elastic[*struct{}] `json:"alias,omitempty"`
Blob elastic.Elastic[[]byte] `json:"blob,omitempty"`
Bool elastic.Elastic[fielddatatype.Boolean] `json:"bool,omitempty"`
Byte elastic.Elastic[int8] `json:"byte,omitempty"`
Comp elastic.Elastic[string] `json:"comp,omitempty"`
ConstantKwd elastic.Elastic[string] `json:"constant_kwd,omitempty"`
Date elastic.Elastic[AllOptionalDateDate] `json:"date,omitempty"`
DateNano elastic.Elastic[AllOptionalDateNanoDate] `json:"dateNano,omitempty"`
DateRange elastic.Elastic[fielddatatype.Range[builtin.Default]] `json:"date_range,omitempty"`
DenseVector sliceund.Und[[3]float64] `json:"dense_vector,omitempty"`
Double elastic.Elastic[float64] `json:"double,omitempty"`
DoubleRange elastic.Elastic[fielddatatype.Range[float64]] `json:"double_range,omitempty"`
Flattened elastic.Elastic[map[string]any] `json:"flattened,omitempty"`
Float elastic.Elastic[float32] `json:"float,omitempty"`
FloatRange elastic.Elastic[fielddatatype.Range[float32]] `json:"float_range,omitempty"`
Geopoint elastic.Elastic[fielddatatype.GeoPoint] `json:"geopoint,omitempty"`
Geoshape elastic.Elastic[fielddatatype.GeoShape] `json:"geoshape,omitempty"`
HalfFloat elastic.Elastic[float32] `json:"half_float,omitempty"`
Histogram elastic.Elastic[fielddatatype.Histogram] `json:"histogram,omitempty"`
Integer elastic.Elastic[int32] `json:"integer,omitempty"`
IntegerRange elastic.Elastic[fielddatatype.Range[int32]] `json:"integer_range,omitempty"`
IpAddr elastic.Elastic[netip.Addr] `json:"ip_addr,omitempty"`
IpRange elastic.Elastic[fielddatatype.Range[netip.Addr]] `json:"ip_range,omitempty"`
Join elastic.Elastic[map[string]any] `json:"join,omitempty"`
Kwd elastic.Elastic[string] `json:"kwd,omitempty"`
Long elastic.Elastic[int64] `json:"long,omitempty"`
LongRange elastic.Elastic[fielddatatype.Range[int64]] `json:"long_range,omitempty"`
Nested elastic.Elastic[AllOptionalNestedObjectRaw] `json:"nested,omitempty"`
Object elastic.Elastic[AllOptionalObjectObjectRaw] `json:"object,omitempty"`
Point elastic.Elastic[map[string]any] `json:"point,omitempty"`
Query elastic.Elastic[map[string]any] `json:"query,omitempty"`
RankFeature elastic.Elastic[float64] `json:"rank_feature,omitempty"`
RankFeatures elastic.Elastic[map[string]float64] `json:"rank_features,omitempty"`
ScaledFloat elastic.Elastic[float64] `json:"scaled_float,omitempty"`
SearchAsYouType elastic.Elastic[string] `json:"search_as_you_type,omitempty"`
Shape elastic.Elastic[fielddatatype.GeoShape] `json:"shape,omitempty"`
Short elastic.Elastic[int16] `json:"short,omitempty"`
Text elastic.Elastic[string] `json:"text,omitempty"`
TextWTokenCount elastic.Elastic[string] `json:"text_w_token_count,omitempty"`
UnsignedLong elastic.Elastic[uint64] `json:"unsigned_long,omitempty"`
Version elastic.Elastic[string] `json:"version,omitempty"`
Wildcard elastic.Elastic[string] `json:"wildcard,omitempty"`
}
func (AllOptionalRaw) ToPlain ¶
func (d AllOptionalRaw) ToPlain() AllOptional
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type AllRaw ¶
type AllRaw struct {
Agg elastic.Elastic[fielddatatype.AggregateMetricDouble] `json:"agg,omitempty"`
Alias elastic.Elastic[*struct{}] `json:"alias,omitempty"`
Blob elastic.Elastic[[]byte] `json:"blob,omitempty"`
Bool elastic.Elastic[fielddatatype.Boolean] `json:"bool,omitempty"`
Byte elastic.Elastic[int8] `json:"byte,omitempty"`
Comp elastic.Elastic[string] `json:"comp,omitempty"`
ConstantKwd elastic.Elastic[string] `json:"constant_kwd,omitempty"`
Date elastic.Elastic[AllDateDate] `json:"date,omitempty"`
DateNano elastic.Elastic[AllDateNanoDate] `json:"dateNano,omitempty"`
DateRange elastic.Elastic[fielddatatype.Range[builtin.Default]] `json:"date_range,omitempty"`
DenseVector sliceund.Und[[3]float64] `json:"dense_vector,omitempty"`
Double elastic.Elastic[float64] `json:"double,omitempty"`
DoubleRange elastic.Elastic[fielddatatype.Range[float64]] `json:"double_range,omitempty"`
Flattened elastic.Elastic[map[string]any] `json:"flattened,omitempty"`
Float elastic.Elastic[float32] `json:"float,omitempty"`
FloatRange elastic.Elastic[fielddatatype.Range[float32]] `json:"float_range,omitempty"`
Geopoint elastic.Elastic[fielddatatype.GeoPoint] `json:"geopoint,omitempty"`
Geoshape elastic.Elastic[fielddatatype.GeoShape] `json:"geoshape,omitempty"`
HalfFloat elastic.Elastic[float32] `json:"half_float,omitempty"`
Histogram elastic.Elastic[fielddatatype.Histogram] `json:"histogram,omitempty"`
Integer elastic.Elastic[int32] `json:"integer,omitempty"`
IntegerRange elastic.Elastic[fielddatatype.Range[int32]] `json:"integer_range,omitempty"`
IpAddr elastic.Elastic[netip.Addr] `json:"ip_addr,omitempty"`
IpRange elastic.Elastic[fielddatatype.Range[netip.Addr]] `json:"ip_range,omitempty"`
Join elastic.Elastic[map[string]any] `json:"join,omitempty"`
Kwd elastic.Elastic[string] `json:"kwd,omitempty"`
Long elastic.Elastic[int64] `json:"long,omitempty"`
LongRange elastic.Elastic[fielddatatype.Range[int64]] `json:"long_range,omitempty"`
Nested elastic.Elastic[AllNestedObjectRaw] `json:"nested,omitempty"`
Object elastic.Elastic[AllObjectObjectRaw] `json:"object,omitempty"`
Point elastic.Elastic[map[string]any] `json:"point,omitempty"`
Query elastic.Elastic[map[string]any] `json:"query,omitempty"`
RankFeature elastic.Elastic[float64] `json:"rank_feature,omitempty"`
RankFeatures elastic.Elastic[map[string]float64] `json:"rank_features,omitempty"`
ScaledFloat elastic.Elastic[float64] `json:"scaled_float,omitempty"`
SearchAsYouType elastic.Elastic[string] `json:"search_as_you_type,omitempty"`
Shape elastic.Elastic[fielddatatype.GeoShape] `json:"shape,omitempty"`
Short elastic.Elastic[int16] `json:"short,omitempty"`
Text elastic.Elastic[string] `json:"text,omitempty"`
TextWTokenCount elastic.Elastic[string] `json:"text_w_token_count,omitempty"`
UnsignedLong elastic.Elastic[uint64] `json:"unsigned_long,omitempty"`
Version elastic.Elastic[string] `json:"version,omitempty"`
Wildcard elastic.Elastic[string] `json:"wildcard,omitempty"`
}
type Conversion ¶
type Conversion struct {
MultipleOptional *[]ConversionMultipleOptionalNested `json:"multiple_optional"`
MultipleRequired []ConversionMultipleRequiredNested `json:"multiple_required"`
SingleOptional *ConversionSingleOptionalObject `json:"single_optional"`
SingleRequired ConversionSingleRequiredObject `json:"single_required"`
}
func (Conversion) ToRaw ¶
func (d Conversion) ToRaw() ConversionRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionMultipleOptionalNameObject ¶
type ConversionMultipleOptionalNameObject struct {
First string `json:"first"`
Last string `json:"last"`
}
type ConversionMultipleOptionalNameObjectRaw ¶
type ConversionMultipleOptionalNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
}
func (ConversionMultipleOptionalNameObjectRaw) ToPlain ¶
func (d ConversionMultipleOptionalNameObjectRaw) ToPlain() ConversionMultipleOptionalNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionMultipleOptionalNested ¶
type ConversionMultipleOptionalNested struct {
Age int32 `json:"age"`
Name ConversionMultipleOptionalNameObject `json:"name"`
}
func (ConversionMultipleOptionalNested) ToRaw ¶
func (d ConversionMultipleOptionalNested) ToRaw() ConversionMultipleOptionalNestedRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionMultipleOptionalNestedRaw ¶
type ConversionMultipleOptionalNestedRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[ConversionMultipleOptionalNameObjectRaw] `json:"name,omitempty"`
}
func (ConversionMultipleOptionalNestedRaw) ToPlain ¶
func (d ConversionMultipleOptionalNestedRaw) ToPlain() ConversionMultipleOptionalNested
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionMultipleRequiredNameObject ¶
type ConversionMultipleRequiredNameObject struct {
First string `json:"first"`
Last string `json:"last"`
}
type ConversionMultipleRequiredNameObjectRaw ¶
type ConversionMultipleRequiredNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
}
func (ConversionMultipleRequiredNameObjectRaw) ToPlain ¶
func (d ConversionMultipleRequiredNameObjectRaw) ToPlain() ConversionMultipleRequiredNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionMultipleRequiredNested ¶
type ConversionMultipleRequiredNested struct {
Age int32 `json:"age"`
Name ConversionMultipleRequiredNameObject `json:"name"`
}
func (ConversionMultipleRequiredNested) ToRaw ¶
func (d ConversionMultipleRequiredNested) ToRaw() ConversionMultipleRequiredNestedRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionMultipleRequiredNestedRaw ¶
type ConversionMultipleRequiredNestedRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[ConversionMultipleRequiredNameObjectRaw] `json:"name,omitempty"`
}
func (ConversionMultipleRequiredNestedRaw) ToPlain ¶
func (d ConversionMultipleRequiredNestedRaw) ToPlain() ConversionMultipleRequiredNested
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionRaw ¶
type ConversionRaw struct {
MultipleOptional elastic.Elastic[ConversionMultipleOptionalNestedRaw] `json:"multiple_optional,omitempty"`
MultipleRequired elastic.Elastic[ConversionMultipleRequiredNestedRaw] `json:"multiple_required,omitempty"`
SingleOptional elastic.Elastic[ConversionSingleOptionalObjectRaw] `json:"single_optional,omitempty"`
SingleRequired elastic.Elastic[ConversionSingleRequiredObjectRaw] `json:"single_required,omitempty"`
}
func (ConversionRaw) ToPlain ¶
func (d ConversionRaw) ToPlain() Conversion
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionSingleOptionalNameObject ¶
type ConversionSingleOptionalNameObject struct {
First string `json:"first"`
Last string `json:"last"`
}
func (ConversionSingleOptionalNameObject) ToRaw ¶
func (d ConversionSingleOptionalNameObject) ToRaw() ConversionSingleOptionalNameObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionSingleOptionalNameObjectRaw ¶
type ConversionSingleOptionalNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
}
func (ConversionSingleOptionalNameObjectRaw) ToPlain ¶
func (d ConversionSingleOptionalNameObjectRaw) ToPlain() ConversionSingleOptionalNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionSingleOptionalObject ¶
type ConversionSingleOptionalObject struct {
Age int32 `json:"age"`
Name ConversionSingleOptionalNameObject `json:"name"`
}
func (ConversionSingleOptionalObject) ToRaw ¶
func (d ConversionSingleOptionalObject) ToRaw() ConversionSingleOptionalObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionSingleOptionalObjectRaw ¶
type ConversionSingleOptionalObjectRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[ConversionSingleOptionalNameObjectRaw] `json:"name,omitempty"`
}
func (ConversionSingleOptionalObjectRaw) ToPlain ¶
func (d ConversionSingleOptionalObjectRaw) ToPlain() ConversionSingleOptionalObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionSingleRequiredNameObject ¶
type ConversionSingleRequiredNameObject struct {
First string `json:"first"`
Last string `json:"last"`
}
func (ConversionSingleRequiredNameObject) ToRaw ¶
func (d ConversionSingleRequiredNameObject) ToRaw() ConversionSingleRequiredNameObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionSingleRequiredNameObjectRaw ¶
type ConversionSingleRequiredNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
}
func (ConversionSingleRequiredNameObjectRaw) ToPlain ¶
func (d ConversionSingleRequiredNameObjectRaw) ToPlain() ConversionSingleRequiredNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionSingleRequiredObject ¶
type ConversionSingleRequiredObject struct {
Age int32 `json:"age"`
Name ConversionSingleRequiredNameObject `json:"name"`
}
func (ConversionSingleRequiredObject) ToRaw ¶
func (d ConversionSingleRequiredObject) ToRaw() ConversionSingleRequiredObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type ConversionSingleRequiredObjectRaw ¶
type ConversionSingleRequiredObjectRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[ConversionSingleRequiredNameObjectRaw] `json:"name,omitempty"`
}
func (ConversionSingleRequiredObjectRaw) ToPlain ¶
func (d ConversionSingleRequiredObjectRaw) ToPlain() ConversionSingleRequiredObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type Dynamic ¶
type Dynamic struct {
NestedInherit DynamicNestedInheritNested `json:"nested_inherit"`
NestedRuntime DynamicNestedRuntimeNested `json:"nested_runtime"`
NestedStrict DynamicNestedStrictNested `json:"nested_strict"`
ObjectFalse DynamicObjectFalseObject `json:"object_false"`
}
func (Dynamic) ToRaw ¶
func (d Dynamic) ToRaw() DynamicRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type DynamicNestedInheritNameObject ¶
type DynamicNestedInheritNameObject struct {
First string `json:"first"`
Last string `json:"last"`
}
func (DynamicNestedInheritNameObject) ToRaw ¶
func (d DynamicNestedInheritNameObject) ToRaw() DynamicNestedInheritNameObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type DynamicNestedInheritNameObjectRaw ¶
type DynamicNestedInheritNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
}
func (DynamicNestedInheritNameObjectRaw) ToPlain ¶
func (d DynamicNestedInheritNameObjectRaw) ToPlain() DynamicNestedInheritNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type DynamicNestedInheritNested ¶
type DynamicNestedInheritNested struct {
Age int32 `json:"age"`
Name DynamicNestedInheritNameObject `json:"name"`
}
func (DynamicNestedInheritNested) ToRaw ¶
func (d DynamicNestedInheritNested) ToRaw() DynamicNestedInheritNestedRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type DynamicNestedInheritNestedRaw ¶
type DynamicNestedInheritNestedRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[DynamicNestedInheritNameObjectRaw] `json:"name,omitempty"`
}
func (DynamicNestedInheritNestedRaw) ToPlain ¶
func (d DynamicNestedInheritNestedRaw) ToPlain() DynamicNestedInheritNested
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type DynamicNestedRuntimeNameObject ¶
type DynamicNestedRuntimeNameObject struct {
First string `json:"first"`
Last string `json:"last"`
AdditionalProperties_ map[string]any
}
func (DynamicNestedRuntimeNameObject) MarshalJSON ¶
func (d DynamicNestedRuntimeNameObject) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (DynamicNestedRuntimeNameObject) ToRaw ¶
func (d DynamicNestedRuntimeNameObject) ToRaw() DynamicNestedRuntimeNameObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*DynamicNestedRuntimeNameObject) UnmarshalJSON ¶
func (d *DynamicNestedRuntimeNameObject) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type DynamicNestedRuntimeNameObjectRaw ¶
type DynamicNestedRuntimeNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
AdditionalProperties_ map[string]any
}
func (DynamicNestedRuntimeNameObjectRaw) MarshalJSON ¶
func (d DynamicNestedRuntimeNameObjectRaw) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (DynamicNestedRuntimeNameObjectRaw) ToPlain ¶
func (d DynamicNestedRuntimeNameObjectRaw) ToPlain() DynamicNestedRuntimeNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*DynamicNestedRuntimeNameObjectRaw) UnmarshalJSON ¶
func (d *DynamicNestedRuntimeNameObjectRaw) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type DynamicNestedRuntimeNested ¶
type DynamicNestedRuntimeNested struct {
Age int32 `json:"age"`
Name DynamicNestedRuntimeNameObject `json:"name"`
AdditionalProperties_ map[string]any
}
func (DynamicNestedRuntimeNested) MarshalJSON ¶
func (d DynamicNestedRuntimeNested) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (DynamicNestedRuntimeNested) ToRaw ¶
func (d DynamicNestedRuntimeNested) ToRaw() DynamicNestedRuntimeNestedRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*DynamicNestedRuntimeNested) UnmarshalJSON ¶
func (d *DynamicNestedRuntimeNested) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type DynamicNestedRuntimeNestedRaw ¶
type DynamicNestedRuntimeNestedRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[DynamicNestedRuntimeNameObjectRaw] `json:"name,omitempty"`
AdditionalProperties_ map[string]any
}
func (DynamicNestedRuntimeNestedRaw) MarshalJSON ¶
func (d DynamicNestedRuntimeNestedRaw) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (DynamicNestedRuntimeNestedRaw) ToPlain ¶
func (d DynamicNestedRuntimeNestedRaw) ToPlain() DynamicNestedRuntimeNested
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*DynamicNestedRuntimeNestedRaw) UnmarshalJSON ¶
func (d *DynamicNestedRuntimeNestedRaw) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type DynamicNestedStrictNameObject ¶
func (DynamicNestedStrictNameObject) ToRaw ¶
func (d DynamicNestedStrictNameObject) ToRaw() DynamicNestedStrictNameObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type DynamicNestedStrictNameObjectRaw ¶
type DynamicNestedStrictNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
}
func (DynamicNestedStrictNameObjectRaw) ToPlain ¶
func (d DynamicNestedStrictNameObjectRaw) ToPlain() DynamicNestedStrictNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type DynamicNestedStrictNested ¶
type DynamicNestedStrictNested struct {
Age int32 `json:"age"`
Name DynamicNestedStrictNameObject `json:"name"`
}
func (DynamicNestedStrictNested) ToRaw ¶
func (d DynamicNestedStrictNested) ToRaw() DynamicNestedStrictNestedRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type DynamicNestedStrictNestedRaw ¶
type DynamicNestedStrictNestedRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[DynamicNestedStrictNameObjectRaw] `json:"name,omitempty"`
}
func (DynamicNestedStrictNestedRaw) ToPlain ¶
func (d DynamicNestedStrictNestedRaw) ToPlain() DynamicNestedStrictNested
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
type DynamicObjectFalseNameObject ¶
type DynamicObjectFalseNameObject struct {
First string `json:"first"`
Last string `json:"last"`
AdditionalProperties_ map[string]any
}
func (DynamicObjectFalseNameObject) MarshalJSON ¶
func (d DynamicObjectFalseNameObject) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (DynamicObjectFalseNameObject) ToRaw ¶
func (d DynamicObjectFalseNameObject) ToRaw() DynamicObjectFalseNameObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*DynamicObjectFalseNameObject) UnmarshalJSON ¶
func (d *DynamicObjectFalseNameObject) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type DynamicObjectFalseNameObjectRaw ¶
type DynamicObjectFalseNameObjectRaw struct {
First elastic.Elastic[string] `json:"first,omitempty"`
Last elastic.Elastic[string] `json:"last,omitempty"`
AdditionalProperties_ map[string]any
}
func (DynamicObjectFalseNameObjectRaw) MarshalJSON ¶
func (d DynamicObjectFalseNameObjectRaw) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (DynamicObjectFalseNameObjectRaw) ToPlain ¶
func (d DynamicObjectFalseNameObjectRaw) ToPlain() DynamicObjectFalseNameObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*DynamicObjectFalseNameObjectRaw) UnmarshalJSON ¶
func (d *DynamicObjectFalseNameObjectRaw) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type DynamicObjectFalseObject ¶
type DynamicObjectFalseObject struct {
Age int32 `json:"age"`
Name DynamicObjectFalseNameObject `json:"name"`
AdditionalProperties_ map[string]any
}
func (DynamicObjectFalseObject) MarshalJSON ¶
func (d DynamicObjectFalseObject) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (DynamicObjectFalseObject) ToRaw ¶
func (d DynamicObjectFalseObject) ToRaw() DynamicObjectFalseObjectRaw
ToRaw converts d into its plain equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*DynamicObjectFalseObject) UnmarshalJSON ¶
func (d *DynamicObjectFalseObject) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type DynamicObjectFalseObjectRaw ¶
type DynamicObjectFalseObjectRaw struct {
Age elastic.Elastic[int32] `json:"age,omitempty"`
Name elastic.Elastic[DynamicObjectFalseNameObjectRaw] `json:"name,omitempty"`
AdditionalProperties_ map[string]any
}
func (DynamicObjectFalseObjectRaw) MarshalJSON ¶
func (d DynamicObjectFalseObjectRaw) MarshalJSON() ([]byte, error)
MarshalJSON implements json.Marshaler so that both known fields and additional properties are marshaled into a same JSON object.
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
func (DynamicObjectFalseObjectRaw) ToPlain ¶
func (d DynamicObjectFalseObjectRaw) ToPlain() DynamicObjectFalseObject
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.
func (*DynamicObjectFalseObjectRaw) UnmarshalJSON ¶
func (d *DynamicObjectFalseObjectRaw) UnmarshalJSON(data []byte) error
UnmarshalJSON implements json.Unmarshaler to add the special handling rule where additional fields in the input JSON object are stored into the AdditionalProperties_ field
The presence of this implementation indicates the dynamic field for this object are defined to be other than "strict" in its mapping.json.
type DynamicRaw ¶
type DynamicRaw struct {
NestedInherit elastic.Elastic[DynamicNestedInheritNestedRaw] `json:"nested_inherit,omitempty"`
NestedRuntime elastic.Elastic[DynamicNestedRuntimeNestedRaw] `json:"nested_runtime,omitempty"`
NestedStrict elastic.Elastic[DynamicNestedStrictNestedRaw] `json:"nested_strict,omitempty"`
ObjectFalse elastic.Elastic[DynamicObjectFalseObjectRaw] `json:"object_false,omitempty"`
}
func (DynamicRaw) ToPlain ¶
func (d DynamicRaw) ToPlain() Dynamic
ToPlain converts d into its raw equivalent. It avoids copying data where it is possilbe. Mutation to fields is not advised.