spec

package module
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 30, 2024 License: Apache-2.0 Imports: 1 Imported by: 0

README

spec

Hand ports of https://github.com/elastic/elasticsearch-specification

LICENSE

The original code is governed under the license described in ELASTICSEARCH_SPECIFICATION_LICENSE

Other modifications made by the author is governed under the LICENSE that can be found in ../LICENSE

Documentation

Overview

https://github.com/elastic/elasticsearch-specification/blob/76e25d34bff1060e300c95f4be468ef88e4f3465/specification/_types/Scripting.ts

  • Licensed to Elasticsearch B.V. under one or more contributor
  • license agreements. See the NOTICE file distributed with
  • this work for additional information regarding copyright
  • ownership. Elasticsearch B.V. licenses this file to you under
  • the Apache License, Version 2.0 (the "License"); you may
  • not use this file except in compliance with the License.
  • You may obtain a copy of the License at *
  • http://www.apache.org/licenses/LICENSE-2.0 *
  • Unless required by applicable law or agreed to in writing,
  • software distributed under the License is distributed on an
  • "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  • KIND, either express or implied. See the License for the
  • specific language governing permissions and limitations
  • under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type InlineScript

type InlineScript struct {
	ScriptBase
	Lang    sliceund.Und[ScriptLanguage]    `json:"lang,omitempty"`
	Options sliceund.Und[map[string]string] `json:"options,omitempty"`
	Source  string                          `json:"source"`
}

* @shortcut_property source

type Script

type Script struct {
	ScriptBase
	Lang    sliceund.Und[ScriptLanguage]    `json:"lang,omitempty"`
	Options sliceund.Und[map[string]string] `json:"options,omitempty"`
	Source  sliceund.Und[string]            `json:"source,omitempty"`
	Id      sliceund.Und[string]            `json:"id,omitempty"`
}

Script = InlineScript | StoredScriptId

func (Script) InlineScript

func (s Script) InlineScript() InlineScript

func (Script) IsInlineScript

func (s Script) IsInlineScript() bool

func (Script) IsStoredScriptId

func (s Script) IsStoredScriptId() bool

func (Script) StoredScriptId

func (s Script) StoredScriptId() StoredScriptId

type ScriptBase

type ScriptBase struct {
	Params sliceund.Und[map[string]any] `json:"params,omitempty"`
}

type ScriptField

type ScriptField struct {
	Script        Script             `json:"script"`
	IgnoreFailure sliceund.Und[bool] `json:"ignore_failure,omitempty"`
}

type ScriptLanguage

type ScriptLanguage string
const (
	Painless   ScriptLanguage = "painless"
	Expression ScriptLanguage = "expression"
	Mustache   ScriptLanguage = "mustache"
	Java       ScriptLanguage = "java"
)

type StoredScript

type StoredScript struct {
	Lang    ScriptLanguage                  `json:"lang"`
	Options sliceund.Und[map[string]string] `json:"options,omitempty"`
	Source  string                          `json:"source"`
}

type StoredScriptId

type StoredScriptId struct {
	ScriptBase
	Id string `json:"id"`
}

Directories

Path Synopsis
https://github.com/elastic/elasticsearch-specification/blob/76e25d34bff1060e300c95f4be468ef88e4f3465/specification/indices/_types/NumericFielddata.ts
https://github.com/elastic/elasticsearch-specification/blob/76e25d34bff1060e300c95f4be468ef88e4f3465/specification/indices/_types/NumericFielddata.ts
indexstate
Hand port of https://github.com/elastic/elasticsearch-specification/blob/76e25d34bff1060e300c95f4be468ef88e4f3465/specification/indices/_types/IndexState.ts
Hand port of https://github.com/elastic/elasticsearch-specification/blob/76e25d34bff1060e300c95f4be468ef88e4f3465/specification/indices/_types/IndexState.ts
This is implemented by the official document.
This is implemented by the official document.
TimeSeriesMetricType
Hand port of https://github.com/elastic/elasticsearch-specification/blob/76e25d34bff1060e300c95f4be468ef88e4f3465/specification/_types/mapping/TimeSeriesMetricType.ts
Hand port of https://github.com/elastic/elasticsearch-specification/blob/76e25d34bff1060e300c95f4be468ef88e4f3465/specification/_types/mapping/TimeSeriesMetricType.ts
runtime_field_type
Hand port of https://github.com/elastic/elasticsearch-specification/blob/76e25d34bff1060e300c95f4be468ef88e4f3465/specification/_types/mapping/RuntimeFields.ts
Hand port of https://github.com/elastic/elasticsearch-specification/blob/76e25d34bff1060e300c95f4be468ef88e4f3465/specification/_types/mapping/RuntimeFields.ts

Jump to